@@ -15,6 +15,7 @@ plugins = []
 
 # To archive plugins {{{
 
+
 class PML2PMLZ(FileTypePlugin):
     name = 'PML to PMLZ'
     author = 'John Schember'
@@ -45,6 +46,7 @@ class PML2PMLZ(FileTypePlugin):
 
         return of.name
 
+
 class TXT2TXTZ(FileTypePlugin):
     name = 'TXT to TXTZ'
     author = 'John Schember'
@@ -124,6 +126,8 @@ plugins += [HTML2ZIP, PML2PMLZ, TXT2TXTZ, ArchiveExtract,]
 # }}}
 
 # Metadata reader plugins {{{
+
+
 class ComicMetadataReader(MetadataReaderPlugin):
 
     name = 'Read comic metadata'
@@ -164,6 +168,7 @@ class ComicMetadataReader(MetadataReaderPlugin):
             mi.cover_data = (ext.lower(), data)
         return mi
 
+
 class CHMMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read CHM metadata'
@@ -187,6 +192,7 @@ class EPUBMetadataReader(MetadataReaderPlugin):
             return get_quick_metadata(stream)
         return get_metadata(stream)
 
+
 class FB2MetadataReader(MetadataReaderPlugin):
 
     name        = 'Read FB2 metadata'
@@ -197,6 +203,7 @@ class FB2MetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.fb2 import get_metadata
         return get_metadata(stream)
 
+
 class HTMLMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read HTML metadata'
@@ -207,6 +214,7 @@ class HTMLMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.html import get_metadata
         return get_metadata(stream)
 
+
 class HTMLZMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read HTMLZ metadata'
@@ -218,6 +226,7 @@ class HTMLZMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.extz import get_metadata
         return get_metadata(stream)
 
+
 class IMPMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read IMP metadata'
@@ -229,6 +238,7 @@ class IMPMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.imp import get_metadata
         return get_metadata(stream)
 
+
 class LITMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read LIT metadata'
@@ -239,6 +249,7 @@ class LITMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.lit import get_metadata
         return get_metadata(stream)
 
+
 class LRFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read LRF metadata'
@@ -249,6 +260,7 @@ class LRFMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.lrf.meta import get_metadata
         return get_metadata(stream)
 
+
 class LRXMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read LRX metadata'
@@ -259,6 +271,7 @@ class LRXMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.lrx import get_metadata
         return get_metadata(stream)
 
+
 class MOBIMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read MOBI metadata'
@@ -269,6 +282,7 @@ class MOBIMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.mobi import get_metadata
         return get_metadata(stream)
 
+
 class ODTMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read ODT metadata'
@@ -279,6 +293,7 @@ class ODTMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.odt import get_metadata
         return get_metadata(stream)
 
+
 class DocXMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read DOCX metadata'
@@ -289,6 +304,7 @@ class DocXMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.docx import get_metadata
         return get_metadata(stream)
 
+
 class OPFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read OPF metadata'
@@ -299,6 +315,7 @@ class OPFMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.opf import get_metadata
         return get_metadata(stream)[0]
 
+
 class PDBMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read PDB metadata'
@@ -310,6 +327,7 @@ class PDBMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.pdb import get_metadata
         return get_metadata(stream)
 
+
 class PDFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read PDF metadata'
@@ -322,6 +340,7 @@ class PDFMetadataReader(MetadataReaderPlugin):
             return get_quick_metadata(stream)
         return get_metadata(stream)
 
+
 class PMLMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read PML metadata'
@@ -333,6 +352,7 @@ class PMLMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.pml import get_metadata
         return get_metadata(stream)
 
+
 class RARMetadataReader(MetadataReaderPlugin):
 
     name = 'Read RAR metadata'
@@ -343,6 +363,7 @@ class RARMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.rar import get_metadata
         return get_metadata(stream)
 
+
 class RBMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read RB metadata'
@@ -354,6 +375,7 @@ class RBMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.rb import get_metadata
         return get_metadata(stream)
 
+
 class RTFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read RTF metadata'
@@ -364,6 +386,7 @@ class RTFMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.rtf import get_metadata
         return get_metadata(stream)
 
+
 class SNBMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read SNB metadata'
@@ -375,6 +398,7 @@ class SNBMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.snb import get_metadata
         return get_metadata(stream)
 
+
 class TOPAZMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read Topaz metadata'
@@ -385,6 +409,7 @@ class TOPAZMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.topaz import get_metadata
         return get_metadata(stream)
 
+
 class TXTMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read TXT metadata'
@@ -396,6 +421,7 @@ class TXTMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.txt import get_metadata
         return get_metadata(stream)
 
+
 class TXTZMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read TXTZ metadata'
@@ -407,6 +433,7 @@ class TXTZMetadataReader(MetadataReaderPlugin):
         from calibre.ebooks.metadata.extz import get_metadata
         return get_metadata(stream)
 
+
 class ZipMetadataReader(MetadataReaderPlugin):
 
     name = 'Read ZIP metadata'
@@ -424,6 +451,7 @@ plugins += [x for x in list(locals().values()) if isinstance(x, type) and
 
 # Metadata writer plugins {{{
 
+
 class EPUBMetadataWriter(MetadataWriterPlugin):
 
     name = 'Set EPUB metadata'
@@ -436,9 +464,12 @@ class EPUBMetadataWriter(MetadataWriterPlugin):
         set_metadata(stream, mi, apply_null=self.apply_null, force_identifiers=self.force_identifiers, add_missing_cover='disable-add-missing-cover' != q)
 
     def customization_help(self, gui=False):
-        return _('Enter {0}{1}{2} below to have the EPUB metadata writer plugin not'
-                 ' add cover images to EPUB files that have no existing cover image.').format(
-                     '<i>' if gui else '', 'disable-add-missing-cover', '</i>' if gui else '')
+        h = 'disable-add-missing-cover'
+        if gui:
+            h = '<i>' + h + '</i>'
+        return _('Enter {0} below to have the EPUB metadata writer plugin not'
+                 ' add cover images to EPUB files that have no existing cover image.').format(h)
+
 
 class FB2MetadataWriter(MetadataWriterPlugin):
 
@@ -450,6 +481,7 @@ class FB2MetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.fb2 import set_metadata
         set_metadata(stream, mi, apply_null=self.apply_null)
 
+
 class HTMLZMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set HTMLZ metadata'
@@ -461,6 +493,7 @@ class HTMLZMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.extz import set_metadata
         set_metadata(stream, mi)
 
+
 class LRFMetadataWriter(MetadataWriterPlugin):
 
     name = 'Set LRF metadata'
@@ -471,6 +504,7 @@ class LRFMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.lrf.meta import set_metadata
         set_metadata(stream, mi)
 
+
 class MOBIMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set MOBI metadata'
@@ -482,6 +516,7 @@ class MOBIMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.mobi import set_metadata
         set_metadata(stream, mi)
 
+
 class PDBMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set PDB metadata'
@@ -493,6 +528,7 @@ class PDBMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.pdb import set_metadata
         set_metadata(stream, mi)
 
+
 class PDFMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set PDF metadata'
@@ -504,6 +540,7 @@ class PDFMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.pdf import set_metadata
         set_metadata(stream, mi)
 
+
 class RTFMetadataWriter(MetadataWriterPlugin):
 
     name = 'Set RTF metadata'
@@ -514,6 +551,7 @@ class RTFMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.rtf import set_metadata
         set_metadata(stream, mi)
 
+
 class TOPAZMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set TOPAZ metadata'
@@ -525,6 +563,7 @@ class TOPAZMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.topaz import set_metadata
         set_metadata(stream, mi)
 
+
 class TXTZMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set TXTZ metadata'
@@ -536,6 +575,7 @@ class TXTZMetadataWriter(MetadataWriterPlugin):
         from calibre.ebooks.metadata.extz import set_metadata
         set_metadata(stream, mi)
 
+
 class DocXMetadataWriter(MetadataWriterPlugin):
 
     name        = 'Set DOCX metadata'
@@ -660,7 +700,7 @@ from calibre.devices.cybook.driver import CYBOOK, ORIZON, MUSE
 from calibre.devices.eb600.driver import (EB600, COOL_ER, SHINEBOOK, TOLINO,
                 POCKETBOOK360, GER2, ITALICA, ECLICTO, DBOOK, INVESBOOK,
                 BOOQ, ELONEX, POCKETBOOK301, MENTOR, POCKETBOOK602,
-                POCKETBOOK701, POCKETBOOK360P, PI2, POCKETBOOK622)
+                POCKETBOOK701, POCKETBOOK360P, PI2, POCKETBOOK622, POCKETBOOKHD)
 from calibre.devices.iliad.driver import ILIAD
 from calibre.devices.irexdr.driver import IREXDR1000, IREXDR800
 from calibre.devices.jetbook.driver import (JETBOOK, MIBUK, JETBOOK_MINI,
@@ -706,7 +746,7 @@ plugins += [
     JETBOOK, JETBOOK_MINI, MIBUK, JETBOOK_COLOR,
     SHINEBOOK,
     POCKETBOOK360, POCKETBOOK301, POCKETBOOK602, POCKETBOOK701, POCKETBOOK360P,
-    POCKETBOOK622, PI2,
+    POCKETBOOK622, PI2, POCKETBOOKHD,
     KINDLE, KINDLE2, KINDLE_DX, KINDLE_FIRE,
     NOOK, NOOK_COLOR,
     PRS505, PRST1,
@@ -788,180 +828,215 @@ plugins += [GoogleBooks, GoogleImages, Amazon, Edelweiss, OpenLibrary, ISBNDB, O
 
 # Interface Actions {{{
 
+
 class ActionAdd(InterfaceActionBase):
     name = 'Add Books'
     actual_plugin = 'calibre.gui2.actions.add:AddAction'
     description = _('Add books to calibre or the connected device')
 
+
 class ActionFetchAnnotations(InterfaceActionBase):
     name = 'Fetch Annotations'
     actual_plugin = 'calibre.gui2.actions.annotate:FetchAnnotationsAction'
     description = _('Fetch annotations from a connected Kindle (experimental)')
 
+
 class ActionGenerateCatalog(InterfaceActionBase):
     name = 'Generate Catalog'
     actual_plugin = 'calibre.gui2.actions.catalog:GenerateCatalogAction'
     description = _('Generate a catalog of the books in your calibre library')
 
+
 class ActionConvert(InterfaceActionBase):
     name = 'Convert Books'
     actual_plugin = 'calibre.gui2.actions.convert:ConvertAction'
     description = _('Convert books to various ebook formats')
 
+
 class ActionPolish(InterfaceActionBase):
     name = 'Polish Books'
     actual_plugin = 'calibre.gui2.actions.polish:PolishAction'
     description = _('Fine tune your ebooks')
 
+
 class ActionEditToC(InterfaceActionBase):
     name = 'Edit ToC'
     actual_plugin = 'calibre.gui2.actions.toc_edit:ToCEditAction'
     description = _('Edit the Table of Contents in your books')
 
+
 class ActionDelete(InterfaceActionBase):
     name = 'Remove Books'
     actual_plugin = 'calibre.gui2.actions.delete:DeleteAction'
     description = _('Delete books from your calibre library or connected device')
 
+
 class ActionEmbed(InterfaceActionBase):
     name = 'Embed Metadata'
     actual_plugin = 'calibre.gui2.actions.embed:EmbedAction'
     description = _('Embed updated metadata into the actual book files in your calibre library')
 
+
 class ActionEditMetadata(InterfaceActionBase):
     name = 'Edit Metadata'
     actual_plugin = 'calibre.gui2.actions.edit_metadata:EditMetadataAction'
     description = _('Edit the metadata of books in your calibre library')
 
+
 class ActionView(InterfaceActionBase):
     name = 'View'
     actual_plugin = 'calibre.gui2.actions.view:ViewAction'
     description = _('Read books in your calibre library')
 
+
 class ActionFetchNews(InterfaceActionBase):
     name = 'Fetch News'
     actual_plugin = 'calibre.gui2.actions.fetch_news:FetchNewsAction'
     description = _('Download news from the internet in ebook form')
 
+
 class ActionQuickview(InterfaceActionBase):
     name = 'Show Quickview'
     actual_plugin = 'calibre.gui2.actions.show_quickview:ShowQuickviewAction'
     description = _('Show a list of related books quickly')
 
+
 class ActionTagMapper(InterfaceActionBase):
     name = 'Tag Mapper'
     actual_plugin = 'calibre.gui2.actions.tag_mapper:TagMapAction'
     description = _('Filter/transform the tags for books in the library')
 
+
 class ActionTemplateTester(InterfaceActionBase):
     name = 'Template Tester'
     actual_plugin = 'calibre.gui2.actions.show_template_tester:ShowTemplateTesterAction'
     description = _('Show an editor for testing templates')
 
+
 class ActionSaveToDisk(InterfaceActionBase):
     name = 'Save To Disk'
     actual_plugin = 'calibre.gui2.actions.save_to_disk:SaveToDiskAction'
     description = _('Export books from your calibre library to the hard disk')
 
+
 class ActionShowBookDetails(InterfaceActionBase):
     name = 'Show Book Details'
     actual_plugin = 'calibre.gui2.actions.show_book_details:ShowBookDetailsAction'
     description = _('Show book details in a separate popup')
 
+
 class ActionRestart(InterfaceActionBase):
     name = 'Restart'
     actual_plugin = 'calibre.gui2.actions.restart:RestartAction'
     description = _('Restart calibre')
 
+
 class ActionOpenFolder(InterfaceActionBase):
     name = 'Open Folder'
     actual_plugin = 'calibre.gui2.actions.open:OpenFolderAction'
     description = _('Open the folder that contains the book files in your'
             ' calibre library')
 
+
 class ActionSendToDevice(InterfaceActionBase):
     name = 'Send To Device'
     actual_plugin = 'calibre.gui2.actions.device:SendToDeviceAction'
     description = _('Send books to the connected device')
 
+
 class ActionConnectShare(InterfaceActionBase):
     name = 'Connect Share'
     actual_plugin = 'calibre.gui2.actions.device:ConnectShareAction'
     description = _('Send books via email or the web also connect to iTunes or'
             ' folders on your computer as if they are devices')
 
+
 class ActionHelp(InterfaceActionBase):
     name = 'Help'
     actual_plugin = 'calibre.gui2.actions.help:HelpAction'
     description = _('Browse the calibre User Manual')
 
+
 class ActionPreferences(InterfaceActionBase):
     name = 'Preferences'
     actual_plugin = 'calibre.gui2.actions.preferences:PreferencesAction'
     description = _('Customize calibre')
 
+
 class ActionSimilarBooks(InterfaceActionBase):
     name = 'Similar Books'
     actual_plugin = 'calibre.gui2.actions.similar_books:SimilarBooksAction'
     description = _('Easily find books similar to the currently selected one')
 
+
 class ActionChooseLibrary(InterfaceActionBase):
     name = 'Choose Library'
     actual_plugin = 'calibre.gui2.actions.choose_library:ChooseLibraryAction'
     description = _('Switch between different calibre libraries and perform'
             ' maintenance on them')
 
+
 class ActionAddToLibrary(InterfaceActionBase):
     name = 'Add To Library'
     actual_plugin = 'calibre.gui2.actions.add_to_library:AddToLibraryAction'
     description = _('Copy books from the device to your calibre library')
 
+
 class ActionEditCollections(InterfaceActionBase):
     name = 'Edit Collections'
     actual_plugin = 'calibre.gui2.actions.edit_collections:EditCollectionsAction'
     description = _('Edit the collections in which books are placed on your device')
 
+
 class ActionMatchBooks(InterfaceActionBase):
     name = 'Match Books'
     actual_plugin = 'calibre.gui2.actions.match_books:MatchBookAction'
     description = _('Match book on the devices to books in the library')
 
+
 class ActionCopyToLibrary(InterfaceActionBase):
     name = 'Copy To Library'
     actual_plugin = 'calibre.gui2.actions.copy_to_library:CopyToLibraryAction'
     description = _('Copy a book from one calibre library to another')
 
+
 class ActionTweakEpub(InterfaceActionBase):
     name = 'Tweak ePub'
     actual_plugin = 'calibre.gui2.actions.tweak_epub:TweakEpubAction'
     description = _('Edit ebooks in the epub or azw3 formats')
 
+
 class ActionUnpackBook(InterfaceActionBase):
     name = 'Unpack Book'
     actual_plugin = 'calibre.gui2.actions.unpack_book:UnpackBookAction'
     description = _('Make small changes to epub or htmlz files in your calibre library')
 
+
 class ActionNextMatch(InterfaceActionBase):
     name = 'Next Match'
     actual_plugin = 'calibre.gui2.actions.next_match:NextMatchAction'
     description = _('Find the next or previous match when searching in '
             'your calibre library in highlight mode')
 
+
 class ActionPickRandom(InterfaceActionBase):
     name = 'Pick Random Book'
     actual_plugin = 'calibre.gui2.actions.random:PickRandomAction'
     description = _('Choose a random book from your calibre library')
 
+
 class ActionSortBy(InterfaceActionBase):
     name = 'Sort By'
     actual_plugin = 'calibre.gui2.actions.sort:SortByAction'
     description = _('Sort the list of books')
 
+
 class ActionMarkBooks(InterfaceActionBase):
     name = 'Mark Books'
     actual_plugin = 'calibre.gui2.actions.mark_books:MarkBooksAction'
     description = _('Temporarily mark books')
 
+
 class ActionStore(InterfaceActionBase):
     name = 'Store'
     author = 'John Schember'
@@ -979,6 +1054,7 @@ class ActionStore(InterfaceActionBase):
         from calibre.gui2.store.config.store import save_settings as save
         save(config_widget)
 
+
 class ActionPluginUpdater(InterfaceActionBase):
     name = 'Plugin Updater'
     author = 'Grant Drake'
@@ -999,6 +1075,7 @@ plugins += [ActionAdd, ActionFetchAnnotations, ActionGenerateCatalog,
 
 # Preferences Plugins {{{
 
+
 class LookAndFeel(PreferencesPlugin):
     name = 'Look & Feel'
     icon = I('lookfeel.png')
@@ -1011,6 +1088,7 @@ class LookAndFeel(PreferencesPlugin):
     description = _('Adjust the look and feel of the calibre interface'
             ' to suit your tastes')
 
+
 class Behavior(PreferencesPlugin):
     name = 'Behavior'
     icon = I('config.png')
@@ -1022,6 +1100,7 @@ class Behavior(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.behavior'
     description = _('Change the way calibre behaves')
 
+
 class Columns(PreferencesPlugin):
     name = 'Custom Columns'
     icon = I('column.png')
@@ -1033,6 +1112,7 @@ class Columns(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.columns'
     description = _('Add/remove your own columns to the calibre book list')
 
+
 class Toolbar(PreferencesPlugin):
     name = 'Toolbar'
     icon = I('wizard.png')
@@ -1045,6 +1125,7 @@ class Toolbar(PreferencesPlugin):
     description = _('Customize the toolbars and context menus, changing which'
             ' actions are available in each')
 
+
 class Search(PreferencesPlugin):
     name = 'Search'
     icon = I('search.png')
@@ -1056,6 +1137,7 @@ class Search(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.search'
     description = _('Customize the way searching for books works in calibre')
 
+
 class InputOptions(PreferencesPlugin):
     name = 'Input Options'
     icon = I('arrow-down.png')
@@ -1072,6 +1154,7 @@ class InputOptions(PreferencesPlugin):
         self.config_widget = 'calibre.gui2.preferences.conversion:InputOptions'
         return PreferencesPlugin.create_widget(self, *args, **kwargs)
 
+
 class CommonOptions(PreferencesPlugin):
     name = 'Common Options'
     icon = I('convert.png')
@@ -1083,6 +1166,7 @@ class CommonOptions(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.conversion:CommonOptions'
     description = _('Set conversion options common to all formats')
 
+
 class OutputOptions(PreferencesPlugin):
     name = 'Output Options'
     icon = I('arrow-up.png')
@@ -1094,6 +1178,7 @@ class OutputOptions(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.conversion:OutputOptions'
     description = _('Set conversion options specific to each output format')
 
+
 class Adding(PreferencesPlugin):
     name = 'Adding'
     icon = I('add_book.png')
@@ -1106,6 +1191,7 @@ class Adding(PreferencesPlugin):
     description = _('Control how calibre reads metadata from files when '
             'adding books')
 
+
 class Saving(PreferencesPlugin):
     name = 'Saving'
     icon = I('save.png')
@@ -1118,6 +1204,7 @@ class Saving(PreferencesPlugin):
     description = _('Control how calibre exports files from its database '
             'to disk when using Save to disk')
 
+
 class Sending(PreferencesPlugin):
     name = 'Sending'
     icon = I('sync.png')
@@ -1130,6 +1217,7 @@ class Sending(PreferencesPlugin):
     description = _('Control how calibre transfers files to your '
             'ebook reader')
 
+
 class Plugboard(PreferencesPlugin):
     name = 'Plugboard'
     icon = I('plugboard.png')
@@ -1141,6 +1229,7 @@ class Plugboard(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.plugboard'
     description = _('Change metadata fields before saving/sending')
 
+
 class TemplateFunctions(PreferencesPlugin):
     name = 'TemplateFunctions'
     icon = I('template_funcs.png')
@@ -1152,6 +1241,7 @@ class TemplateFunctions(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.template_functions'
     description = _('Create your own template functions')
 
+
 class Email(PreferencesPlugin):
     name = 'Email'
     icon = I('mail.png')
@@ -1164,6 +1254,7 @@ class Email(PreferencesPlugin):
     description = _('Setup sharing of books via email. Can be used '
             'for automatic sending of downloaded news to your devices')
 
+
 class Server(PreferencesPlugin):
     name = 'Server'
     icon = I('network-server.png')
@@ -1177,6 +1268,7 @@ class Server(PreferencesPlugin):
             'give you access to your calibre library from anywhere, '
             'on any device, over the internet')
 
+
 class MetadataSources(PreferencesPlugin):
     name = 'Metadata download'
     icon = I('download-metadata.png')
@@ -1188,6 +1280,7 @@ class MetadataSources(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.metadata_sources'
     description = _('Control how calibre downloads ebook metadata from the net')
 
+
 class IgnoredDevices(PreferencesPlugin):
     name = 'Ignored Devices'
     icon = I('reader.png')
@@ -1213,9 +1306,10 @@ class Plugins(PreferencesPlugin):
     description = _('Add/remove/customize various bits of calibre '
             'functionality')
 
+
 class Tweaks(PreferencesPlugin):
     name = 'Tweaks'
-    icon = I('drawer.png')
+    icon = I('tweaks.png')
     gui_name = _('Tweaks')
     category = 'Advanced'
     gui_category = _('Advanced')
@@ -1224,6 +1318,7 @@ class Tweaks(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.tweaks'
     description = _('Fine tune how calibre behaves in various contexts')
 
+
 class Keyboard(PreferencesPlugin):
     name = 'Keyboard'
     icon = I('keyboard-prefs.png')
@@ -1235,6 +1330,7 @@ class Keyboard(PreferencesPlugin):
     config_widget = 'calibre.gui2.preferences.keyboard'
     description = _('Customize the keyboard shortcuts used by calibre')
 
+
 class Misc(PreferencesPlugin):
     name = 'Misc'
     icon = I('exec.png')
@@ -1254,6 +1350,8 @@ plugins += [LookAndFeel, Behavior, Columns, Toolbar, Search, InputOptions,
 # }}}
 
 # Store plugins {{{
+
+
 class StoreAmazonKindleStore(StoreBase):
     name = 'Amazon Kindle'
     description = u'Kindle books from Amazon.'
@@ -1263,6 +1361,7 @@ class StoreAmazonKindleStore(StoreBase):
     formats = ['KINDLE']
     affiliate = False
 
+
 class StoreSonyStore(StoreBase):
     name = 'SONY Reader Store'
     description = u'SONY Reader books.'
@@ -1273,12 +1372,14 @@ class StoreSonyStore(StoreBase):
     formats = ['SONY']
     affiliate = False
 
+
 class StoreSonyAUStore(StoreSonyStore):
     name = 'SONY Reader (Australia) Store'
     description = u'SONY Reader books (Australia).'
     actual_plugin = 'calibre.gui2.store.stores.sony_au_plugin:SonyStore'
     headquarters = 'AU'
 
+
 class StoreAmazonAUKindleStore(StoreBase):
     name = 'Amazon AU Kindle'
     author = u'Kovid Goyal'
@@ -1288,6 +1389,7 @@ class StoreAmazonAUKindleStore(StoreBase):
     headquarters = 'AU'
     formats = ['KINDLE']
 
+
 class StoreAmazonCAKindleStore(StoreBase):
     name = 'Amazon CA Kindle'
     author = u'Kovid Goyal'
@@ -1297,6 +1399,7 @@ class StoreAmazonCAKindleStore(StoreBase):
     headquarters = 'CA'
     formats = ['KINDLE']
 
+
 class StoreAmazonINKindleStore(StoreBase):
     name = 'Amazon IN Kindle'
     author = u'Kovid Goyal'
@@ -1306,6 +1409,7 @@ class StoreAmazonINKindleStore(StoreBase):
     headquarters = 'IN'
     formats = ['KINDLE']
 
+
 class StoreAmazonDEKindleStore(StoreBase):
     name = 'Amazon DE Kindle'
     author = 'Kovid Goyal'
@@ -1315,6 +1419,7 @@ class StoreAmazonDEKindleStore(StoreBase):
     headquarters = 'DE'
     formats = ['KINDLE']
 
+
 class StoreAmazonFRKindleStore(StoreBase):
     name = 'Amazon FR Kindle'
     author = 'Kovid Goyal'
@@ -1324,6 +1429,7 @@ class StoreAmazonFRKindleStore(StoreBase):
     headquarters = 'FR'
     formats = ['KINDLE']
 
+
 class StoreAmazonITKindleStore(StoreBase):
     name = 'Amazon IT Kindle'
     author = 'Kovid Goyal'
@@ -1333,6 +1439,7 @@ class StoreAmazonITKindleStore(StoreBase):
     headquarters = 'IT'
     formats = ['KINDLE']
 
+
 class StoreAmazonESKindleStore(StoreBase):
     name = 'Amazon ES Kindle'
     author = 'Kovid Goyal'
@@ -1342,6 +1449,7 @@ class StoreAmazonESKindleStore(StoreBase):
     headquarters = 'ES'
     formats = ['KINDLE']
 
+
 class StoreAmazonUKKindleStore(StoreBase):
     name = 'Amazon UK Kindle'
     author = 'Kovid Goyal'
@@ -1351,6 +1459,7 @@ class StoreAmazonUKKindleStore(StoreBase):
     headquarters = 'UK'
     formats = ['KINDLE']
 
+
 class StoreArchiveOrgStore(StoreBase):
     name = 'Archive.org'
     description = u'An Internet library offering permanent access for researchers, historians, scholars, people with disabilities, and the general public to historical collections that exist in digital format.'  # noqa
@@ -1360,6 +1469,7 @@ class StoreArchiveOrgStore(StoreBase):
     headquarters = 'US'
     formats = ['DAISY', 'DJVU', 'EPUB', 'MOBI', 'PDF', 'TXT']
 
+
 class StoreBubokPublishingStore(StoreBase):
     name = 'Bubok Spain'
     description = u'Bubok Publishing is a publisher, library and store of books of authors from all around the world. They have a big amount of books of a lot of topics'  # noqa
@@ -1369,6 +1479,7 @@ class StoreBubokPublishingStore(StoreBase):
     headquarters = 'ES'
     formats = ['EPUB', 'PDF']
 
+
 class StoreBubokPortugalStore(StoreBase):
     name = 'Bubok Portugal'
     description = u'Bubok Publishing Portugal is a publisher, library and store of books of authors from Portugal. They have a big amount of books of a lot of topics'  # noqa
@@ -1378,6 +1489,7 @@ class StoreBubokPortugalStore(StoreBase):
     headquarters = 'PT'
     formats = ['EPUB', 'PDF']
 
+
 class StoreBaenWebScriptionStore(StoreBase):
     name = 'Baen Ebooks'
     description = u'Sci-Fi & Fantasy brought to you by Jim Baen.'
@@ -1387,6 +1499,7 @@ class StoreBaenWebScriptionStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'LIT', 'LRF', 'MOBI', 'RB', 'RTF', 'ZIP']
 
+
 class StoreBNStore(StoreBase):
     name = 'Barnes and Noble'
     description = u'The world\'s largest book seller. As the ultimate destination for book lovers, Barnes & Noble.com offers an incredible array of content.'
@@ -1395,6 +1508,7 @@ class StoreBNStore(StoreBase):
     headquarters = 'US'
     formats = ['NOOK']
 
+
 class StoreBeamEBooksDEStore(StoreBase):
     name = 'Beam EBooks DE'
     author = 'Charles Haley'
@@ -1406,6 +1520,7 @@ class StoreBeamEBooksDEStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreBiblioStore(StoreBase):
     name = u'Библио.бг'
     author = 'Alex Stanev'
@@ -1415,6 +1530,7 @@ class StoreBiblioStore(StoreBase):
     headquarters = 'BG'
     formats = ['EPUB, PDF']
 
+
 class StoreCdpStore(StoreBase):
     name = 'Cdp.pl'
     author = u'Tomasz Długosz'
@@ -1426,6 +1542,7 @@ class StoreCdpStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreChitankaStore(StoreBase):
     name = u'Моята библиотека'
     author = 'Alex Stanev'
@@ -1436,6 +1553,7 @@ class StoreChitankaStore(StoreBase):
     headquarters = 'BG'
     formats = ['FB2', 'EPUB', 'TXT', 'SFB']
 
+
 class StoreEbookNLStore(StoreBase):
     name = 'eBook.nl'
     description = u'De eBookwinkel van Nederland'
@@ -1445,6 +1563,7 @@ class StoreEbookNLStore(StoreBase):
     formats = ['EPUB', 'PDF']
     affiliate = False
 
+
 class StoreEbookpointStore(StoreBase):
     name = 'Ebookpoint'
     author = u'Tomasz Długosz'
@@ -1456,6 +1575,7 @@ class StoreEbookpointStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreEbookscomStore(StoreBase):
     name = 'eBooks.com'
     description = u'Sells books in multiple electronic formats in all categories. Technical infrastructure is cutting edge, robust and scalable, with servers in the US and Europe.'  # noqa
@@ -1465,6 +1585,7 @@ class StoreEbookscomStore(StoreBase):
     formats = ['EPUB', 'LIT', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreEbooksGratuitsStore(StoreBase):
     name = 'EbooksGratuits.com'
     description = u'Ebooks Libres et Gratuits'
@@ -1484,6 +1605,7 @@ class StoreEbooksGratuitsStore(StoreBase):
 #     formats = ['EPUB', 'PDF']
 #     affiliate = True
 
+
 class StoreEKnigiStore(StoreBase):
     name = u'еКниги'
     author = 'Alex Stanev'
@@ -1494,6 +1616,7 @@ class StoreEKnigiStore(StoreBase):
     formats = ['EPUB', 'PDF', 'HTML']
     affiliate = True
 
+
 class StoreEmpikStore(StoreBase):
     name = 'Empik'
     author = u'Tomasz Długosz'
@@ -1504,6 +1627,7 @@ class StoreEmpikStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreFeedbooksStore(StoreBase):
     name = 'Feedbooks'
     description = u'Feedbooks is a cloud publishing and distribution service, connected to a large ecosystem of reading systems and social networks. Provides a variety of genres from independent and classic books.'  # noqa
@@ -1512,6 +1636,7 @@ class StoreFeedbooksStore(StoreBase):
     headquarters = 'FR'
     formats = ['EPUB', 'MOBI', 'PDF']
 
+
 class StoreGoogleBooksStore(StoreBase):
     name = 'Google Books'
     description = u'Google Books'
@@ -1520,6 +1645,7 @@ class StoreGoogleBooksStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'PDF', 'TXT']
 
+
 class StoreGutenbergStore(StoreBase):
     name = 'Project Gutenberg'
     description = u'The first producer of free ebooks. Free in the United States because their copyright has expired. They may not be free of copyright in other countries. Readers outside of the United States must check the copyright laws of their countries before downloading or redistributing our ebooks.'  # noqa
@@ -1529,6 +1655,7 @@ class StoreGutenbergStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'HTML', 'MOBI', 'PDB', 'TXT']
 
+
 class StoreKoboStore(StoreBase):
     name = 'Kobo'
     description = u'With over 2.3 million eBooks to browse we have engaged readers in over 200 countries in Kobo eReading. Our eBook listings include New York Times Bestsellers, award winners, classics and more!'  # noqa
@@ -1538,6 +1665,7 @@ class StoreKoboStore(StoreBase):
     formats = ['EPUB']
     affiliate = True
 
+
 class StoreKoobeStore(StoreBase):
     name = 'Koobe'
     author = u'Tomasz Długosz'
@@ -1549,6 +1677,7 @@ class StoreKoobeStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreLegimiStore(StoreBase):
     name = 'Legimi'
     author = u'Tomasz Długosz'
@@ -1559,6 +1688,7 @@ class StoreLegimiStore(StoreBase):
     formats = ['EPUB', 'PDF', 'MOBI']
     affiliate = True
 
+
 class StoreLibreDEStore(StoreBase):
     name = 'ebook.de'
     author = 'Charles Haley'
@@ -1569,6 +1699,7 @@ class StoreLibreDEStore(StoreBase):
     formats = ['EPUB', 'PDF']
     affiliate = True
 
+
 class StoreLitResStore(StoreBase):
     name = 'LitRes'
     description = u'ebooks from LitRes.ru'
@@ -1580,6 +1711,7 @@ class StoreLitResStore(StoreBase):
     formats = ['EPUB', 'TXT', 'RTF', 'HTML', 'FB2', 'LRF', 'PDF', 'MOBI', 'LIT', 'ISILO3', 'JAR', 'RB', 'PRC']
     affiliate = True
 
+
 class StoreManyBooksStore(StoreBase):
     name = 'ManyBooks'
     description = u'Public domain and creative commons works from many sources.'
@@ -1589,6 +1721,7 @@ class StoreManyBooksStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'FB2', 'JAR', 'LIT', 'LRF', 'MOBI', 'PDB', 'PDF', 'RB', 'RTF', 'TCR', 'TXT', 'ZIP']
 
+
 class StoreMillsBoonUKStore(StoreBase):
     name = 'Mills and Boon UK'
     author = 'Charles Haley'
@@ -1599,6 +1732,7 @@ class StoreMillsBoonUKStore(StoreBase):
     formats = ['EPUB']
     affiliate = True
 
+
 class StoreMobileReadStore(StoreBase):
     name = 'MobileRead'
     description = u'Ebooks handcrafted with the utmost care.'
@@ -1608,6 +1742,7 @@ class StoreMobileReadStore(StoreBase):
     headquarters = 'CH'
     formats = ['EPUB', 'IMP', 'LRF', 'LIT', 'MOBI', 'PDF']
 
+
 class StoreNextoStore(StoreBase):
     name = 'Nexto'
     author = u'Tomasz Długosz'
@@ -1618,6 +1753,7 @@ class StoreNextoStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreNookUKStore(StoreBase):
     name = 'Nook UK'
     author = 'Charles Haley'
@@ -1627,6 +1763,7 @@ class StoreNookUKStore(StoreBase):
     headquarters = 'UK'
     formats = ['NOOK']
 
+
 class StoreOpenBooksStore(StoreBase):
     name = 'Open Books'
     description = u'Comprehensive listing of DRM free ebooks from a variety of sources provided by users of calibre.'
@@ -1635,6 +1772,7 @@ class StoreOpenBooksStore(StoreBase):
     drm_free_only = True
     headquarters = 'US'
 
+
 class StoreOzonRUStore(StoreBase):
     name = 'OZON.ru'
     description = u'ebooks from OZON.ru'
@@ -1646,6 +1784,7 @@ class StoreOzonRUStore(StoreBase):
     formats = ['TXT', 'PDF', 'DJVU', 'RTF', 'DOC', 'JAR', 'FB2']
     affiliate = True
 
+
 class StorePragmaticBookshelfStore(StoreBase):
     name = 'Pragmatic Bookshelf'
     description = u'The Pragmatic Bookshelf\'s collection of programming and tech books avaliable as ebooks.'
@@ -1655,6 +1794,7 @@ class StorePragmaticBookshelfStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'MOBI', 'PDF']
 
+
 class StorePublioStore(StoreBase):
     name = 'Publio'
     description = u'Publio.pl to księgarnia internetowa, w której mogą Państwo nabyć e-booki i audiobooki.'
@@ -1665,6 +1805,7 @@ class StorePublioStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreRW2010Store(StoreBase):
     name = 'RW2010'
     description = u'Polski serwis self-publishingowy. Pliki PDF, EPUB i MOBI. Maksymalna cena utworu nie przekracza u nas 10 złotych!'
@@ -1675,6 +1816,7 @@ class StoreRW2010Store(StoreBase):
     headquarters = 'PL'
     formats = ['EPUB', 'MOBI', 'PDF']
 
+
 class StoreSmashwordsStore(StoreBase):
     name = 'Smashwords'
     description = u'An ebook publishing and distribution platform for ebook authors, publishers and readers. Covers many genres and formats.'
@@ -1685,6 +1827,7 @@ class StoreSmashwordsStore(StoreBase):
     formats = ['EPUB', 'HTML', 'LRF', 'MOBI', 'PDB', 'RTF', 'TXT']
     affiliate = True
 
+
 class StoreVirtualoStore(StoreBase):
     name = 'Virtualo'
     author = u'Tomasz Długosz'
@@ -1695,6 +1838,7 @@ class StoreVirtualoStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF']
     affiliate = True
 
+
 class StoreWaterstonesUKStore(StoreBase):
     name = 'Waterstones UK'
     author = 'Charles Haley'
@@ -1705,6 +1849,7 @@ class StoreWaterstonesUKStore(StoreBase):
     formats = ['EPUB', 'PDF']
     affiliate = False
 
+
 class StoreWeightlessBooksStore(StoreBase):
     name = 'Weightless Books'
     description = u'An independent DRM-free ebooksite devoted to ebooks of all sorts.'
@@ -1714,6 +1859,7 @@ class StoreWeightlessBooksStore(StoreBase):
     headquarters = 'US'
     formats = ['EPUB', 'HTML', 'LIT', 'MOBI', 'PDF']
 
+
 class StoreWHSmithUKStore(StoreBase):
     name = 'WH Smith UK'
     author = 'Charles Haley'
@@ -1723,6 +1869,7 @@ class StoreWHSmithUKStore(StoreBase):
     headquarters = 'UK'
     formats = ['EPUB', 'PDF']
 
+
 class StoreWolneLekturyStore(StoreBase):
     name = 'Wolne Lektury'
     author = u'Tomasz Długosz'
@@ -1732,6 +1879,7 @@ class StoreWolneLekturyStore(StoreBase):
     headquarters = 'PL'
     formats = ['EPUB', 'MOBI', 'PDF', 'TXT', 'FB2']
 
+
 class StoreWoblinkStore(StoreBase):
     name = 'Woblink'
     author = u'Tomasz Długosz'
@@ -1742,6 +1890,7 @@ class StoreWoblinkStore(StoreBase):
     formats = ['EPUB', 'MOBI', 'PDF', 'WOBLINK']
     affiliate = True
 
+
 class XinXiiStore(StoreBase):
     name = 'XinXii'
     description = ''
