@@ -1,31 +1,36 @@
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 """ The GUI """
-import os, sys, Queue, threading, glob
+import os, sys, Queue, threading, glob, signal
 from contextlib import contextmanager
 from threading import RLock, Lock
 from urllib import unquote
 from PyQt5.QtWidgets import QStyle  # Gives a nicer error message than import from Qt
 from PyQt5.Qt import (
-    QFileInfo, QObject, QBuffer, Qt, QByteArray, QTranslator,
-    QCoreApplication, QThread, QEvent, QTimer, pyqtSignal, QDateTime,
+    QFileInfo, QObject, QBuffer, Qt, QByteArray, QTranslator, QSocketNotifier,
+    QCoreApplication, QThread, QEvent, QTimer, pyqtSignal, QDateTime, QFontMetrics,
     QDesktopServices, QFileDialog, QFileIconProvider, QSettings, QIcon,
     QApplication, QDialog, QUrl, QFont, QFontDatabase, QLocale, QFontInfo)
 
-ORG_NAME = 'KovidsBrain'
-APP_UID  = 'libprs500'
 from calibre import prints
 from calibre.constants import (islinux, iswindows, isbsd, isfrozen, isosx,
-        plugins, config_dir, filesystem_encoding, isxp)
+        plugins, config_dir, filesystem_encoding, isxp, DEBUG, __version__, __appname__ as APP_UID)
+from calibre.ptempfile import base_dir
 from calibre.utils.config import Config, ConfigProxy, dynamic, JSONConfig
 from calibre.ebooks.metadata import MetaInformation
 from calibre.utils.date import UNDEFINED_DATE
 from calibre.utils.localization import get_lang
 from calibre.utils.filenames import expanduser
+from calibre.utils.file_type_icons import EXT_MAP
+
+try:
+    NO_URL_FORMATTING = QUrl.None_
+except AttributeError:
+    NO_URL_FORMATTING = QUrl.None
 
 # Setup gprefs {{{
 gprefs = JSONConfig('gui')
-defs = gprefs.defaults
+
 
 native_menubar_defaults = {
     'action-layout-menubar': (
@@ -40,105 +45,114 @@ native_menubar_defaults = {
         )
 }
 
-if isosx:
-    defs['action-layout-menubar'] = native_menubar_defaults['action-layout-menubar']
-    defs['action-layout-menubar-device'] = native_menubar_defaults['action-layout-menubar-device']
-    defs['action-layout-toolbar'] = (
-        'Add Books', 'Edit Metadata', None, 'Convert Books', 'View', None,
-        'Choose Library', 'Donate', None, 'Fetch News', 'Store', 'Save To Disk',
-        'Connect Share', None, 'Remove Books', 'Tweak ePub'
-        )
-    defs['action-layout-toolbar-device'] = (
-        'Add Books', 'Edit Metadata', None, 'Convert Books', 'View',
-        'Send To Device', None, None, 'Location Manager', None, None,
-        'Fetch News', 'Store', 'Save To Disk', 'Connect Share', None,
-        'Remove Books',
-        )
-else:
-    defs['action-layout-menubar'] = ()
-    defs['action-layout-menubar-device'] = ()
-    defs['action-layout-toolbar'] = (
-        'Add Books', 'Edit Metadata', None, 'Convert Books', 'View', None,
-        'Store', 'Donate', 'Fetch News', 'Help', None,
-        'Remove Books', 'Choose Library', 'Save To Disk',
-        'Connect Share', 'Tweak ePub', 'Preferences',
-        )
-    defs['action-layout-toolbar-device'] = (
-        'Add Books', 'Edit Metadata', None, 'Convert Books', 'View',
-        'Send To Device', None, None, 'Location Manager', None, None,
-        'Fetch News', 'Save To Disk', 'Store', 'Connect Share', None,
-        'Remove Books', None, 'Help', 'Preferences',
-        )
 
-defs['action-layout-toolbar-child'] = ()
+def create_defs():
+    defs = gprefs.defaults
+    if isosx:
+        defs['action-layout-menubar'] = native_menubar_defaults['action-layout-menubar']
+        defs['action-layout-menubar-device'] = native_menubar_defaults['action-layout-menubar-device']
+        defs['action-layout-toolbar'] = (
+            'Add Books', 'Edit Metadata', None, 'Convert Books', 'View', None,
+            'Choose Library', 'Donate', None, 'Fetch News', 'Store', 'Save To Disk',
+            'Connect Share', None, 'Remove Books', 'Tweak ePub'
+            )
+        defs['action-layout-toolbar-device'] = (
+            'Add Books', 'Edit Metadata', None, 'Convert Books', 'View',
+            'Send To Device', None, None, 'Location Manager', None, None,
+            'Fetch News', 'Store', 'Save To Disk', 'Connect Share', None,
+            'Remove Books',
+            )
+    else:
+        defs['action-layout-menubar'] = ()
+        defs['action-layout-menubar-device'] = ()
+        defs['action-layout-toolbar'] = (
+            'Add Books', 'Edit Metadata', None, 'Convert Books', 'View', None,
+            'Store', 'Donate', 'Fetch News', 'Help', None,
+            'Remove Books', 'Choose Library', 'Save To Disk',
+            'Connect Share', 'Tweak ePub', 'Preferences',
+            )
+        defs['action-layout-toolbar-device'] = (
+            'Add Books', 'Edit Metadata', None, 'Convert Books', 'View',
+            'Send To Device', None, None, 'Location Manager', None, None,
+            'Fetch News', 'Save To Disk', 'Store', 'Connect Share', None,
+            'Remove Books', None, 'Help', 'Preferences',
+            )
 
-defs['action-layout-context-menu'] = (
-        'Edit Metadata', 'Send To Device', 'Save To Disk',
-        'Connect Share', 'Copy To Library', None,
-        'Convert Books', 'View', 'Open Folder', 'Show Book Details',
-        'Similar Books', 'Tweak ePub', None, 'Remove Books',
-        )
+    defs['action-layout-toolbar-child'] = ()
 
-defs['action-layout-context-menu-device'] = (
-        'View', 'Save To Disk', None, 'Remove Books', None,
-        'Add To Library', 'Edit Collections', 'Match Books'
-        )
+    defs['action-layout-context-menu'] = (
+            'Edit Metadata', 'Send To Device', 'Save To Disk',
+            'Connect Share', 'Copy To Library', None,
+            'Convert Books', 'View', 'Open Folder', 'Show Book Details',
+            'Similar Books', 'Tweak ePub', None, 'Remove Books',
+            )
 
-defs['action-layout-context-menu-cover-browser'] = (
-        'Edit Metadata', 'Send To Device', 'Save To Disk',
-        'Connect Share', 'Copy To Library', None,
-        'Convert Books', 'View', 'Open Folder', 'Show Book Details',
-        'Similar Books', 'Tweak ePub', None, 'Remove Books',
-        )
+    defs['action-layout-context-menu-device'] = (
+            'View', 'Save To Disk', None, 'Remove Books', None,
+            'Add To Library', 'Edit Collections', 'Match Books'
+            )
 
-defs['show_splash_screen'] = True
-defs['toolbar_icon_size'] = 'medium'
-defs['automerge'] = 'ignore'
-defs['toolbar_text'] = 'always'
-defs['font'] = None
-defs['tags_browser_partition_method'] = 'first letter'
-defs['tags_browser_collapse_at'] = 100
-defs['tag_browser_dont_collapse'] = []
-defs['edit_metadata_single_layout'] = 'default'
-defs['default_author_link'] = 'https://en.wikipedia.org/w/index.php?search={author}'
-defs['preserve_date_on_ctl'] = True
-defs['manual_add_auto_convert'] = False
-defs['auto_convert_same_fmt'] = False
-defs['cb_fullscreen'] = False
-defs['worker_max_time'] = 0
-defs['show_files_after_save'] = True
-defs['auto_add_path'] = None
-defs['auto_add_check_for_duplicates'] = False
-defs['blocked_auto_formats'] = []
-defs['auto_add_auto_convert'] = True
-defs['auto_add_everything'] = False
-defs['ui_style'] = 'calibre' if iswindows or isosx else 'system'
-defs['tag_browser_old_look'] = False
-defs['book_list_tooltips'] = True
-defs['bd_show_cover'] = True
-defs['bd_overlay_cover_size'] = False
-defs['tags_browser_category_icons'] = {}
-defs['cover_browser_reflections'] = True
-defs['book_list_extra_row_spacing'] = 0
-defs['refresh_book_list_on_bulk_edit'] = True
-defs['cover_grid_width'] = 0
-defs['cover_grid_height'] = 0
-defs['cover_grid_spacing'] = 0
-defs['cover_grid_color'] = (80, 80, 80)
-defs['cover_grid_cache_size_multiple'] = 5
-defs['cover_grid_disk_cache_size'] = 2500
-defs['cover_grid_show_title'] = False
-defs['cover_grid_texture'] = None
-defs['show_vl_tabs'] = False
-defs['show_highlight_toggle_button'] = False
-defs['add_comments_to_email'] = False
-defs['cb_preserve_aspect_ratio'] = False
-defs['show_rating_in_cover_browser'] = True
-defs['gpm_template_editor_font_size'] = 10
-defs['show_emblems'] = False
-defs['emblem_size'] = 32
-defs['emblem_position'] = 'left'
-del defs
+    defs['action-layout-context-menu-cover-browser'] = (
+            'Edit Metadata', 'Send To Device', 'Save To Disk',
+            'Connect Share', 'Copy To Library', None,
+            'Convert Books', 'View', 'Open Folder', 'Show Book Details',
+            'Similar Books', 'Tweak ePub', None, 'Remove Books',
+            )
+
+    defs['show_splash_screen'] = True
+    defs['toolbar_icon_size'] = 'medium'
+    defs['automerge'] = 'ignore'
+    defs['toolbar_text'] = 'always'
+    defs['font'] = None
+    defs['tags_browser_partition_method'] = 'first letter'
+    defs['tags_browser_collapse_at'] = 100
+    defs['tag_browser_dont_collapse'] = []
+    defs['edit_metadata_single_layout'] = 'default'
+    defs['default_author_link'] = 'https://en.wikipedia.org/w/index.php?search={author}'
+    defs['preserve_date_on_ctl'] = True
+    defs['manual_add_auto_convert'] = False
+    defs['auto_convert_same_fmt'] = False
+    defs['cb_fullscreen'] = False
+    defs['worker_max_time'] = 0
+    defs['show_files_after_save'] = True
+    defs['auto_add_path'] = None
+    defs['auto_add_check_for_duplicates'] = False
+    defs['blocked_auto_formats'] = []
+    defs['auto_add_auto_convert'] = True
+    defs['auto_add_everything'] = False
+    defs['ui_style'] = 'calibre' if iswindows or isosx else 'system'
+    defs['tag_browser_old_look'] = False
+    defs['tag_browser_hide_empty_categories'] = False
+    defs['book_list_tooltips'] = True
+    defs['bd_show_cover'] = True
+    defs['bd_overlay_cover_size'] = False
+    defs['tags_browser_category_icons'] = {}
+    defs['cover_browser_reflections'] = True
+    defs['book_list_extra_row_spacing'] = 0
+    defs['refresh_book_list_on_bulk_edit'] = True
+    defs['cover_grid_width'] = 0
+    defs['cover_grid_height'] = 0
+    defs['cover_grid_spacing'] = 0
+    defs['cover_grid_color'] = (80, 80, 80)
+    defs['cover_grid_cache_size_multiple'] = 5
+    defs['cover_grid_disk_cache_size'] = 2500
+    defs['cover_grid_show_title'] = False
+    defs['cover_grid_texture'] = None
+    defs['show_vl_tabs'] = False
+    defs['show_highlight_toggle_button'] = False
+    defs['add_comments_to_email'] = False
+    defs['cb_preserve_aspect_ratio'] = False
+    defs['gpm_template_editor_font_size'] = 10
+    defs['show_emblems'] = False
+    defs['emblem_size'] = 32
+    defs['emblem_position'] = 'left'
+    defs['metadata_diff_mark_rejected'] = False
+    defs['tag_browser_show_counts'] = True
+    defs['row_numbers_in_book_list'] = True
+
+
+create_defs()
+del create_defs
 # }}}
 
 UNDEFINED_QDATETIME = QDateTime(UNDEFINED_DATE)
@@ -146,6 +160,7 @@ UNDEFINED_QDATETIME = QDateTime(UNDEFINED_DATE)
 ALL_COLUMNS = ['title', 'ondevice', 'authors', 'size', 'timestamp', 'rating', 'publisher',
         'tags', 'series', 'pubdate']
 
+
 def _config():  # {{{
     c = Config('gui', 'preferences for the calibre GUI')
     c.add_opt('send_to_storage_card_by_default', default=False,
@@ -248,31 +263,39 @@ def _config():  # {{{
     c.add_opt
     return ConfigProxy(c)
 
+
 config = _config()
+
 # }}}
 
 QSettings.setPath(QSettings.IniFormat, QSettings.UserScope, config_dir)
 QSettings.setPath(QSettings.IniFormat, QSettings.SystemScope, config_dir)
 QSettings.setDefaultFormat(QSettings.IniFormat)
 
+
 def available_heights():
     desktop  = QCoreApplication.instance().desktop()
     return map(lambda x: x.height(), map(desktop.availableGeometry, range(desktop.screenCount())))
 
+
 def available_height():
     desktop  = QCoreApplication.instance().desktop()
     return desktop.availableGeometry().height()
 
+
 def max_available_height():
     return max(available_heights())
 
+
 def min_available_height():
     return min(available_heights())
 
+
 def available_width():
     desktop       = QCoreApplication.instance().desktop()
     return desktop.availableGeometry().width()
 
+
 def get_windows_color_depth():
     import win32gui, win32con, win32print
     hwin = win32gui.GetDesktopWindow()
@@ -281,12 +304,15 @@ def get_windows_color_depth():
     win32gui.ReleaseDC(hwin, hwindc)
     return ans
 
+
 def get_screen_dpi():
     d = QApplication.desktop()
     return (d.logicalDpiX(), d.logicalDpiY())
 
+
 _is_widescreen = None
 
+
 def is_widescreen():
     global _is_widescreen
     if _is_widescreen is None:
@@ -296,6 +322,7 @@ def is_widescreen():
             _is_widescreen = False
     return _is_widescreen
 
+
 def extension(path):
     return os.path.splitext(path)[1][1:].lower()
 
@@ -310,6 +337,7 @@ def warning_dialog(parent, title, msg, det_msg='', show=False,
         return d.exec_()
     return d
 
+
 def error_dialog(parent, title, msg, det_msg='', show=False,
         show_copy_button=True):
     from calibre.gui2.dialogs.message_box import MessageBox
@@ -320,6 +348,7 @@ def error_dialog(parent, title, msg, det_msg='', show=False,
         return d.exec_()
     return d
 
+
 def question_dialog(parent, title, msg, det_msg='', show_copy_button=False,
         default_yes=True,
         # Skippable dialogs
@@ -359,6 +388,7 @@ def question_dialog(parent, title, msg, det_msg='', show_copy_button=False,
 
     return ret
 
+
 def info_dialog(parent, title, msg, det_msg='', show=False,
         show_copy_button=True):
     from calibre.gui2.dialogs.message_box import MessageBox
@@ -369,12 +399,14 @@ def info_dialog(parent, title, msg, det_msg='', show=False,
         return d.exec_()
     return d
 
+
 def show_restart_warning(msg, parent=None):
     d = warning_dialog(parent, _('Restart needed'), msg,
             show_copy_button=False)
     b = d.bb.addButton(_('Restart calibre now'), d.bb.AcceptRole)
     b.setIcon(QIcon(I('lt.png')))
     d.do_restart = False
+
     def rf():
         d.do_restart = True
     b.clicked.connect(rf)
@@ -409,6 +441,7 @@ class Dispatcher(QObject):
     def dispatch(self, args, kwargs):
         self.func(*args, **kwargs)
 
+
 class FunctionDispatcher(QObject):
     '''
     Convenience class to use Qt signals with arbitrary python functions.
@@ -451,6 +484,7 @@ class FunctionDispatcher(QObject):
             res = None
         q.put(res)
 
+
 class GetMetadata(QObject):
     '''
     Convenience class to ensure that metadata readers are used only in the
@@ -489,58 +523,10 @@ class GetMetadata(QObject):
             mi = MetaInformation('', [_('Unknown')])
         self.metadata.emit(id, mi)
 
+
 class FileIconProvider(QFileIconProvider):
 
-    ICONS = {
-             'default' : 'unknown',
-             'dir'     : 'dir',
-             'zero'    : 'zero',
-
-             'jpeg'    : 'jpeg',
-             'jpg'     : 'jpeg',
-             'gif'     : 'gif',
-             'png'     : 'png',
-             'bmp'     : 'bmp',
-             'cbz'     : 'cbz',
-             'cbr'     : 'cbr',
-             'svg'     : 'svg',
-             'html'    : 'html',
-             'htmlz'   : 'html',
-             'htm'     : 'html',
-             'xhtml'   : 'html',
-             'xhtm'    : 'html',
-             'lit'     : 'lit',
-             'lrf'     : 'lrf',
-             'lrx'     : 'lrx',
-             'pdf'     : 'pdf',
-             'pdr'     : 'zero',
-             'rar'     : 'rar',
-             'zip'     : 'zip',
-             'txt'     : 'txt',
-             'text'    : 'txt',
-             'prc'     : 'mobi',
-             'azw'     : 'mobi',
-             'mobi'    : 'mobi',
-             'pobi'    : 'mobi',
-             'mbp'     : 'zero',
-             'azw1'    : 'tpz',
-             'azw2'    : 'azw2',
-             'azw3'    : 'azw3',
-             'azw4'    : 'pdf',
-             'tpz'     : 'tpz',
-             'tan'     : 'zero',
-             'epub'    : 'epub',
-             'fb2'     : 'fb2',
-             'rtf'     : 'rtf',
-             'odt'     : 'odt',
-             'snb'     : 'snb',
-             'djv'     : 'djvu',
-             'djvu'    : 'djvu',
-             'xps'     : 'xps',
-             'oxps'    : 'xps',
-             'docx'    : 'docx',
-             'opml'    : 'opml',
-             }
+    ICONS = EXT_MAP
 
     def __init__(self):
         QFileIconProvider.__init__(self)
@@ -604,17 +590,22 @@ class FileIconProvider(QFileIconProvider):
             return self.icons['default']
         return QFileIconProvider.icon(self, arg)
 
+
 _file_icon_provider = None
+
+
 def initialize_file_icon_provider():
     global _file_icon_provider
     if _file_icon_provider is None:
         _file_icon_provider = FileIconProvider()
 
+
 def file_icon_provider():
     global _file_icon_provider
     initialize_file_icon_provider()
     return _file_icon_provider
 
+
 def select_initial_dir(q):
     while q:
         c = os.path.dirname(q)
@@ -625,7 +616,9 @@ def select_initial_dir(q):
         q = c
     return expanduser(u'~')
 
+
 class FileDialog(QObject):
+
     def __init__(self, title=_('Choose Files'),
                        filters=[],
                        add_all_files_filter=True,
@@ -725,14 +718,87 @@ class FileDialog(QObject):
         return tuple(self.selected_files)
 
 
-def choose_dir(window, name, title, default_dir='~', no_save_dir=False):
-    fd = FileDialog(title=title, filters=[], add_all_files_filter=False,
-            parent=window, name=name, mode=QFileDialog.Directory,
-            default_dir=default_dir, no_save_dir=no_save_dir)
-    dir = fd.get_files()
-    fd.setParent(None)
-    if dir:
-        return dir[0]
+has_windows_file_dialog_helper = False
+if iswindows and 'CALIBRE_NO_NATIVE_FILEDIALOGS' not in os.environ:
+    from calibre.gui2.win_file_dialogs import is_ok as has_windows_file_dialog_helper
+    has_windows_file_dialog_helper = has_windows_file_dialog_helper()
+if has_windows_file_dialog_helper:
+    from calibre.gui2.win_file_dialogs import choose_files, choose_images, choose_dir, choose_save_file
+else:
+
+    def choose_dir(window, name, title, default_dir='~', no_save_dir=False):
+        fd = FileDialog(title=title, filters=[], add_all_files_filter=False,
+                parent=window, name=name, mode=QFileDialog.Directory,
+                default_dir=default_dir, no_save_dir=no_save_dir)
+        dir = fd.get_files()
+        fd.setParent(None)
+        if dir:
+            return dir[0]
+
+    def choose_files(window, name, title,
+                    filters=[], all_files=True, select_only_single_file=False, default_dir=u'~'):
+        '''
+        Ask user to choose a bunch of files.
+        :param name: Unique dialog name used to store the opened directory
+        :param title: Title to show in dialogs titlebar
+        :param filters: list of allowable extensions. Each element of the list
+                        must be a 2-tuple with first element a string describing
+                        the type of files to be filtered and second element a list
+                        of extensions.
+        :param all_files: If True add All files to filters.
+        :param select_only_single_file: If True only one file can be selected
+        '''
+        mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
+        fd = FileDialog(title=title, name=name, filters=filters, default_dir=default_dir,
+                        parent=window, add_all_files_filter=all_files, mode=mode,
+                        )
+        fd.setParent(None)
+        if fd.accepted:
+            return fd.get_files()
+        return None
+
+    def choose_save_file(window, name, title, filters=[], all_files=True, initial_path=None, initial_filename=None):
+        '''
+        Ask user to choose a file to save to. Can be a non-existent file.
+        :param filters: list of allowable extensions. Each element of the list
+                        must be a 2-tuple with first element a string describing
+                        the type of files to be filtered and second element a list
+                        of extensions.
+        :param all_files: If True add All files to filters.
+        :param initial_path: The initially selected path (does not need to exist). Cannot be used with initial_filename.
+        :param initial_filename: If specified, the initially selected path is this filename in the previously used directory. Cannot be used with initial_path.
+        '''
+        kwargs = dict(title=title, name=name, filters=filters,
+                        parent=window, add_all_files_filter=all_files, mode=QFileDialog.AnyFile)
+        if initial_path is not None:
+            kwargs['no_save_dir'] = True
+            kwargs['default_dir'] = initial_path
+        elif initial_filename is not None:
+            kwargs['combine_file_and_saved_dir'] = True
+            kwargs['default_dir'] = initial_filename
+        fd = FileDialog(**kwargs)
+        fd.setParent(None)
+        ans = None
+        if fd.accepted:
+            ans = fd.get_files()
+            if ans:
+                ans = ans[0]
+        return ans
+
+    def choose_images(window, name, title, select_only_single_file=True, formats=None):
+        mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
+        if formats is None:
+            from calibre.gui2.dnd import image_extensions
+            formats = image_extensions()
+        fd = FileDialog(title=title, name=name,
+                        filters=[(_('Images'), list(formats))],
+                        parent=window, add_all_files_filter=False, mode=mode,
+                        )
+        fd.setParent(None)
+        if fd.accepted:
+            return fd.get_files()
+        return None
+
 
 def choose_osx_app(window, name, title, default_dir='/Applications'):
     fd = FileDialog(title=title, parent=window, name=name, mode=QFileDialog.ExistingFile,
@@ -742,67 +808,6 @@ def choose_osx_app(window, name, title, default_dir='/Applications'):
     if app:
         return app
 
-def choose_files(window, name, title,
-                 filters=[], all_files=True, select_only_single_file=False, default_dir=u'~'):
-    '''
-    Ask user to choose a bunch of files.
-    :param name: Unique dialog name used to store the opened directory
-    :param title: Title to show in dialogs titlebar
-    :param filters: list of allowable extensions. Each element of the list
-                    must be a 2-tuple with first element a string describing
-                    the type of files to be filtered and second element a list
-                    of extensions.
-    :param all_files: If True add All files to filters.
-    :param select_only_single_file: If True only one file can be selected
-    '''
-    mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
-    fd = FileDialog(title=title, name=name, filters=filters, default_dir=default_dir,
-                    parent=window, add_all_files_filter=all_files, mode=mode,
-                    )
-    fd.setParent(None)
-    if fd.accepted:
-        return fd.get_files()
-    return None
-
-def choose_save_file(window, name, title, filters=[], all_files=True, initial_path=None, initial_filename=None):
-    '''
-    Ask user to choose a file to save to. Can be a non-existent file.
-    :param filters: list of allowable extensions. Each element of the list
-                     must be a 2-tuple with first element a string describing
-                     the type of files to be filtered and second element a list
-                     of extensions.
-    :param all_files: If True add All files to filters.
-    :param initial_path: The initially selected path (does not need to exist). Cannot be used with initial_filename.
-    :param initial_filename: If specified, the initially selected path is this filename in the previously used directory. Cannot be used with initial_path.
-    '''
-    kwargs = dict(title=title, name=name, filters=filters,
-                    parent=window, add_all_files_filter=all_files, mode=QFileDialog.AnyFile)
-    if initial_path is not None:
-        kwargs['no_save_dir'] = True
-        kwargs['default_dir'] = initial_path
-    elif initial_filename is not None:
-        kwargs['combine_file_and_saved_dir'] = True
-        kwargs['default_dir'] = initial_filename
-    fd = FileDialog(**kwargs)
-    fd.setParent(None)
-    ans = None
-    if fd.accepted:
-        ans = fd.get_files()
-        if ans:
-            ans = ans[0]
-    return ans
-
-def choose_images(window, name, title, select_only_single_file=True,
-                  formats=('png', 'gif', 'jpg', 'jpeg', 'svg')):
-    mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
-    fd = FileDialog(title=title, name=name,
-                    filters=[('Images', list(formats))],
-                    parent=window, add_all_files_filter=False, mode=mode,
-                    )
-    fd.setParent(None)
-    if fd.accepted:
-        return fd.get_files()
-    return None
 
 def pixmap_to_data(pixmap, format='JPEG', quality=90):
     '''
@@ -814,28 +819,42 @@ def pixmap_to_data(pixmap, format='JPEG', quality=90):
     pixmap.save(buf, format, quality=quality)
     return bytes(ba.data())
 
+
 def decouple(prefix):
     ' Ensure that config files used by utility code are not the same as those used by the main calibre GUI '
     dynamic.decouple(prefix)
     from calibre.gui2.widgets import history
     history.decouple(prefix)
 
+
+_gui_prefs = gprefs
+
+
+def gui_prefs():
+    return _gui_prefs
+
+
+def set_gui_prefs(prefs):
+    global _gui_prefs
+    _gui_prefs = prefs
+
+
 class ResizableDialog(QDialog):
 
+    # This class is present only for backwards compat with third party plugins
+    # that might use it. Do not use it in new code.
+
     def __init__(self, *args, **kwargs):
         QDialog.__init__(self, *args)
         self.setupUi(self)
         desktop = QCoreApplication.instance().desktop()
         geom = desktop.availableGeometry(self)
-        nh, nw = geom.height()-25, geom.width()-10
-        if nh < 0:
-            nh = max(800, self.height())
-        if nw < 0:
-            nw = max(600, self.height())
+        nh, nw = max(550, geom.height()-25), max(700, geom.width()-10)
         nh = min(self.height(), nh)
         nw = min(self.width(), nw)
         self.resize(nw, nh)
 
+
 class Translator(QTranslator):
     '''
     Translator to load translations for strings in Qt from the calibre
@@ -858,6 +877,7 @@ qt_app = None
 
 builtin_fonts_loaded = False
 
+
 def load_builtin_fonts():
     global _rating_font, builtin_fonts_loaded
     # Load the builtin fonts and any fonts added to calibre by the user to
@@ -879,13 +899,26 @@ def load_builtin_fonts():
                     if u'calibre Symbols' in fam:
                         _rating_font = u'calibre Symbols'
 
+
 def setup_gui_option_parser(parser):
     if islinux:
         parser.add_option('--detach', default=False, action='store_true',
                           help=_('Detach from the controlling terminal, if any (linux only)'))
 
+
+def show_temp_dir_error(err):
+    import traceback
+    extra = _('Click "Show details" for more information.')
+    if 'CALIBRE_TEMP_DIR' in os.environ:
+        extra = _('The %s environment variable is set. Try unsetting it.') % 'CALIBRE_TEMP_DIR'
+    error_dialog(None, _('Could not create temporary directory'), _(
+        'Could not create temporary directory, calibre cannot start.') + ' ' + extra, det_msg=traceback.format_exc(), show=True)
+
+
 class Application(QApplication):
 
+    shutdown_signal_received = pyqtSignal()
+
     def __init__(self, args, force_calibre_style=False, override_program_name=None, headless=False, color_prefs=gprefs):
         self.file_event_hook = None
         if override_program_name:
@@ -897,7 +930,37 @@ class Application(QApplication):
         self.headless = headless
         qargs = [i.encode('utf-8') if isinstance(i, unicode) else i for i in args]
         self.pi = plugins['progress_indicator'][0]
+        if not isosx and not headless and hasattr(Qt, 'AA_EnableHighDpiScaling'):
+            # On OS X high dpi scaling is turned on automatically by the OS, so we dont need to set it explicitly
+            # This requires Qt >= 5.6
+            for v in ('QT_AUTO_SCREEN_SCALE_FACTOR', 'QT_SCALE_FACTOR', 'QT_SCREEN_SCALE_FACTORS', 'QT_DEVICE_PIXEL_RATIO'):
+                if os.environ.get(v):
+                    break
+            else:
+                # Should probably make a preference to allow the user to
+                # control this, if needed.
+                # Could have options: auto, off, 1.25, 1.5, 1.75, 2, 2.25, 2.5
+                QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
+        QApplication.setOrganizationName('calibre-ebook.com')
+        QApplication.setOrganizationDomain(QApplication.organizationName())
+        QApplication.setApplicationVersion(__version__)
+        QApplication.setApplicationName(APP_UID)
         QApplication.__init__(self, qargs)
+        self.setAttribute(Qt.AA_UseHighDpiPixmaps)
+        try:
+            base_dir()
+        except EnvironmentError as err:
+            if not headless:
+                show_temp_dir_error(err)
+            raise SystemExit('Failed to create temporary directory')
+        if DEBUG and not headless:
+            prints('devicePixelRatio:', self.devicePixelRatio())
+            s = self.primaryScreen()
+            if s:
+                prints('logicalDpi:', s.logicalDotsPerInchX(), 'x', s.logicalDotsPerInchY())
+                prints('physicalDpi:', s.physicalDotsPerInchX(), 'x', s.physicalDotsPerInchY())
+        if not iswindows:
+            self.setup_unix_signals()
         if islinux or isbsd:
             self.setAttribute(Qt.AA_DontUseNativeMenuBar, 'CALIBRE_NO_NATIVE_MENUBAR' in os.environ)
         self.setup_styles(force_calibre_style)
@@ -917,6 +980,7 @@ class Application(QApplication):
             if s is not None:
                 font.setStretch(s)
             QApplication.setFont(font)
+        self.line_height = max(12, QFontMetrics(self.font()).lineSpacing())
 
         dl = QLocale(get_lang())
         if unicode(dl.bcp47Name()) != u'C':
@@ -1048,9 +1112,11 @@ class Application(QApplication):
     @dynamic_property
     def current_custom_colors(self):
         from PyQt5.Qt import QColorDialog, QColor
+
         def fget(self):
             return [col.getRgb() for col in
                     (QColorDialog.customColor(i) for i in xrange(QColorDialog.customCount()))]
+
         def fset(self, colors):
             num = min(len(colors), QColorDialog.customCount())
             for i in xrange(num):
@@ -1074,20 +1140,44 @@ class Application(QApplication):
     def __exit__(self, *args):
         self.setQuitOnLastWindowClosed(True)
 
+    def setup_unix_signals(self):
+        import fcntl
+        read_fd, write_fd = os.pipe()
+        cloexec_flag = getattr(fcntl, 'FD_CLOEXEC', 1)
+        for fd in (read_fd, write_fd):
+            flags = fcntl.fcntl(fd, fcntl.F_GETFD)
+            fcntl.fcntl(fd, fcntl.F_SETFD, flags | cloexec_flag | os.O_NONBLOCK)
+        for sig in (signal.SIGINT, signal.SIGTERM):
+            signal.signal(sig, lambda x, y: None)
+            signal.siginterrupt(sig, False)
+        signal.set_wakeup_fd(write_fd)
+        self.signal_notifier = QSocketNotifier(read_fd, QSocketNotifier.Read, self)
+        self.signal_notifier.setEnabled(True)
+        self.signal_notifier.activated.connect(self.signal_received, type=Qt.QueuedConnection)
+
+    def signal_received(self, read_fd):
+        try:
+            os.read(read_fd, 1024)
+        except EnvironmentError:
+            return
+        self.shutdown_signal_received.emit()
+
+
 _store_app = None
 
+
 @contextmanager
 def sanitize_env_vars():
     '''Unset various environment variables that calibre uses. This
     is needed to prevent library conflicts when launching external utilities.'''
 
     if islinux and isfrozen:
-        env_vars = {'LD_LIBRARY_PATH':'/lib', 'QT_PLUGIN_PATH':'/lib/qt_plugins', 'MAGICK_CODER_MODULE_PATH':None, 'MAGICK_CODER_FILTER_PATH':None}
+        env_vars = {'LD_LIBRARY_PATH':'/lib', 'QT_PLUGIN_PATH':'/lib/qt_plugins'}
     elif iswindows:
-        env_vars = {k:None for k in 'MAGICK_HOME MAGICK_CONFIGURE_PATH MAGICK_CODER_MODULE_PATH MAGICK_FILTER_MODULE_PATH QT_PLUGIN_PATH'.split()}
+        env_vars = {k:None for k in 'QT_PLUGIN_PATH'.split()}
     elif isosx:
-        env_vars = {k:None for k in
-                    'FONTCONFIG_FILE FONTCONFIG_PATH MAGICK_CONFIGURE_PATH MAGICK_CODER_MODULE_PATH MAGICK_FILTER_MODULE_PATH QT_PLUGIN_PATH'.split()}
+        env_vars = {k:None for k in (
+                    'FONTCONFIG_FILE FONTCONFIG_PATH QT_PLUGIN_PATH SSL_CERT_FILE').split()}
     else:
         env_vars = {}
 
@@ -1112,8 +1202,11 @@ def sanitize_env_vars():
                     os.environ[var] = orig
                 elif var in os.environ:
                     del os.environ[var]
+
+
 SanitizeLibraryPath = sanitize_env_vars  # For old plugins
 
+
 def open_url(qurl):
     # Qt 5 requires QApplication to be constructed before trying to use
     # QDesktopServices::openUrl()
@@ -1123,6 +1216,7 @@ def open_url(qurl):
     with sanitize_env_vars():
         QDesktopServices.openUrl(qurl)
 
+
 def get_current_db():
     '''
     This method will try to return the current database in use by the user as
@@ -1136,6 +1230,7 @@ def get_current_db():
     from calibre.library import db
     return db()
 
+
 def open_local_file(path):
     if iswindows:
         with sanitize_env_vars():
@@ -1144,8 +1239,10 @@ def open_local_file(path):
         url = QUrl.fromLocalFile(path)
         open_url(url)
 
+
 _ea_lock = Lock()
 
+
 def ensure_app(headless=True):
     global _store_app
     with _ea_lock:
@@ -1165,6 +1262,7 @@ def ensure_app(headless=True):
             # dont feel like going through all the code and making sure no
             # unhandled exceptions ever occur. All the actual GUI apps already
             # override sys.except_hook with a proper error handler.
+
             def eh(t, v, tb):
                 try:
                     traceback.print_exception(t, v, tb, file=sys.stderr)
@@ -1172,9 +1270,11 @@ def ensure_app(headless=True):
                     pass
             sys.excepthook = eh
 
+
 def app_is_headless():
     return getattr(_store_app, 'headless', False)
 
+
 def must_use_qt(headless=True):
     ''' This function should be called if you want to use Qt for some non-GUI
     task like rendering HTML/SVG or using a headless browser. It will raise a
@@ -1188,6 +1288,7 @@ def must_use_qt(headless=True):
     if gui_thread is not QThread.currentThread():
         raise RuntimeError('Cannot use Qt in non GUI thread')
 
+
 def is_ok_to_use_qt():
     try:
         must_use_qt()
@@ -1195,15 +1296,20 @@ def is_ok_to_use_qt():
         return False
     return True
 
+
 def is_gui_thread():
     global gui_thread
     return gui_thread is QThread.currentThread()
 
+
 _rating_font = 'Arial Unicode MS' if iswindows else 'sans-serif'
+
+
 def rating_font():
     global _rating_font
     return _rating_font
 
+
 def elided_text(text, font=None, width=300, pos='middle'):
     ''' Return a version of text that is no wider than width pixels when
     rendered, replacing characters from the left, middle or right (as per pos)
@@ -1223,6 +1329,7 @@ def elided_text(text, font=None, width=300, pos='middle'):
         text = chomp(text)
     return unicode(text)
 
+
 def find_forms(srcdir):
     base = os.path.join(srcdir, 'calibre', 'gui2')
     forms = []
@@ -1233,9 +1340,11 @@ def find_forms(srcdir):
 
     return forms
 
+
 def form_to_compiled_form(form):
     return form.rpartition('.')[0]+'_ui.py'
 
+
 def build_forms(srcdir, info=None, summary=False, check_for_migration=False):
     import re, cStringIO
     from PyQt5.uic import compileUi
@@ -1244,6 +1353,7 @@ def build_forms(srcdir, info=None, summary=False, check_for_migration=False):
         from calibre import prints
         info = prints
     pat = re.compile(r'''(['"]):/images/([^'"]+)\1''')
+
     def sub(match):
         ans = 'I(%s%s%s)'%(match.group(1), match.group(2), match.group(1))
         return ans
@@ -1278,10 +1388,12 @@ def build_forms(srcdir, info=None, summary=False, check_for_migration=False):
     if force_compile:
         gprefs.set('migrated_forms_to_qt5', True)
 
+
 _df = os.environ.get('CALIBRE_DEVELOP_FROM', None)
 if _df and os.path.exists(_df):
     build_forms(_df, check_for_migration=True)
 
+
 def event_type_name(ev_or_etype):
     from PyQt5.QtCore import QEvent
     etype = ev_or_etype.type() if isinstance(ev_or_etype, QEvent) else ev_or_etype
