@@ -20,18 +20,19 @@ from PyQt5.Qt import (
     QStyledItemDelegate, QTextDocument, QRectF, QIcon, Qt, QApplication,
     QDialog, QVBoxLayout, QLabel, QDialogButtonBox, QStyle, QStackedWidget,
     QWidget, QTableView, QGridLayout, QFontInfo, QPalette, QTimer, pyqtSignal,
-    QAbstractTableModel, QSize, QListView, QPixmap, QModelIndex, QUrl,
-    QAbstractListModel, QColor, QRect, QTextBrowser, QStringListModel, QMenu,
+    QAbstractTableModel, QSize, QListView, QPixmap, QModelIndex,
+    QAbstractListModel, QRect, QTextBrowser, QStringListModel, QMenu,
     QCursor, QHBoxLayout, QPushButton, QSizePolicy)
 from PyQt5.QtWebKitWidgets import QWebView
 
 from calibre.customize.ui import metadata_plugins
-from calibre.ebooks.metadata import authors_to_string
+from calibre.ebooks.metadata import authors_to_string, rating_to_stars
 from calibre.utils.logging import GUILog as Log
 from calibre.ebooks.metadata.sources.identify import urls_from_identifiers
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.opf2 import OPF
 from calibre.gui2 import error_dialog, rating_font, gprefs
+from calibre.gui2.progress_indicator import draw_snake_spinner
 from calibre.utils.date import (utcnow, fromordinal, format_date,
         UNDEFINED_DATE, as_utc)
 from calibre.library.comments import comments_to_html
@@ -41,6 +42,7 @@ from calibre.utils.ipc.simple_worker import fork_job, WorkerError
 from calibre.ptempfile import TemporaryDirectory
 # }}}
 
+
 class RichTextDelegate(QStyledItemDelegate):  # {{{
 
     def __init__(self, parent=None, max_width=160):
@@ -78,8 +80,11 @@ class RichTextDelegate(QStyledItemDelegate):  # {{{
         painter.restore()
 # }}}
 
+
 class CoverDelegate(QStyledItemDelegate):  # {{{
 
+    ICON_SIZE = 150, 200
+
     needs_redraw = pyqtSignal()
 
     def __init__(self, parent):
@@ -88,47 +93,21 @@ class CoverDelegate(QStyledItemDelegate):  # {{{
         self.angle = 0
         self.timer = QTimer(self)
         self.timer.timeout.connect(self.frame_changed)
-        self.color = parent.palette().color(QPalette.WindowText)
+        self.dark_color = parent.palette().color(QPalette.WindowText)
+        self.light_color = parent.palette().color(QPalette.Window)
         self.spinner_width = 64
 
     def frame_changed(self, *args):
-        self.angle = (self.angle+30)%360
+        self.angle = (self.angle-2)%360
         self.needs_redraw.emit()
 
     def start_animation(self):
         self.angle = 0
-        self.timer.start(200)
+        self.timer.start(10)
 
     def stop_animation(self):
         self.timer.stop()
 
-    def draw_spinner(self, painter, rect):
-        width = rect.width()
-
-        outer_radius = (width-1)*0.5
-        inner_radius = (width-1)*0.5*0.38
-
-        capsule_height = outer_radius - inner_radius
-        capsule_width  = int(capsule_height * (0.23 if width > 32 else 0.35))
-        capsule_radius = capsule_width//2
-
-        painter.save()
-        painter.setRenderHint(painter.Antialiasing)
-
-        for i in xrange(12):
-            color = QColor(self.color)
-            color.setAlphaF(1.0 - (i/12.0))
-            painter.setPen(Qt.NoPen)
-            painter.setBrush(color)
-            painter.save()
-            painter.translate(rect.center())
-            painter.rotate(self.angle - i*30.0)
-            painter.drawRoundedRect(-capsule_width*0.5,
-                    -(inner_radius+capsule_height), capsule_width,
-                    capsule_height, capsule_radius, capsule_radius)
-            painter.restore()
-        painter.restore()
-
     def paint(self, painter, option, index):
         QStyledItemDelegate.paint(self, painter, option, index)
         style = QApplication.style()
@@ -136,7 +115,7 @@ class CoverDelegate(QStyledItemDelegate):  # {{{
         if waiting:
             rect = QRect(0, 0, self.spinner_width, self.spinner_width)
             rect.moveCenter(option.rect.center())
-            self.draw_spinner(painter, rect)
+            draw_snake_spinner(painter, rect, self.angle, self.light_color, self.dark_color)
         else:
             # Ensure the cover is rendered over any selection rect
             style.drawItemPixmap(painter, option.rect, Qt.AlignTop|Qt.AlignHCenter,
@@ -144,6 +123,7 @@ class CoverDelegate(QStyledItemDelegate):  # {{{
 
 # }}}
 
+
 class ResultsModel(QAbstractTableModel):  # {{{
 
     COLUMNS = (
@@ -234,6 +214,7 @@ class ResultsModel(QAbstractTableModel):  # {{{
 
 # }}}
 
+
 class ResultsView(QTableView):  # {{{
 
     show_details_signal = pyqtSignal(object)
@@ -292,7 +273,7 @@ class ResultsView(QTableView):  # {{{
                 parts.append('<div>%s: %s</div>'%series)
         if not book.is_null('rating'):
             style = 'style=\'font-family:"%s"\''%f
-            parts.append('<div %s>%s</div>'%(style, '\u2605'*int(book.rating)))
+            parts.append('<div %s>%s</div>'%(style, rating_to_stars(int(2 * book.rating))))
         parts.append('</center>')
         if book.identifiers:
             urls = urls_from_identifiers(book.identifiers)
@@ -331,6 +312,7 @@ class ResultsView(QTableView):  # {{{
 
 # }}}
 
+
 class Comments(QWebView):  # {{{
 
     def __init__(self, parent=None):
@@ -349,7 +331,7 @@ class Comments(QWebView):  # {{{
 
     def link_clicked(self, url):
         from calibre.gui2 import open_url
-        if unicode(url.toString(QUrl.None)).startswith('http://'):
+        if url.scheme() in {'http', 'https'}:
             open_url(url)
 
     def turnoff_scrollbar(self, *args):
@@ -399,6 +381,7 @@ class Comments(QWebView):  # {{{
         return QSize(800, 300)
 # }}}
 
+
 class IdentifyWorker(Thread):  # {{{
 
     def __init__(self, log, abort, title, authors, identifiers, caches):
@@ -456,6 +439,7 @@ class IdentifyWorker(Thread):  # {{{
 
 # }}}
 
+
 class IdentifyWidget(QWidget):  # {{{
 
     rejected = pyqtSignal()
@@ -572,6 +556,7 @@ class IdentifyWidget(QWidget):  # {{{
         self.abort.set()
 # }}}
 
+
 class CoverWorker(Thread):  # {{{
 
     def __init__(self, log, abort, title, authors, identifiers, caches):
@@ -651,6 +636,7 @@ class CoverWorker(Thread):  # {{{
 
 # }}}
 
+
 class CoversModel(QAbstractListModel):  # {{{
 
     def __init__(self, current_cover, parent=None):
@@ -658,8 +644,9 @@ class CoversModel(QAbstractListModel):  # {{{
 
         if current_cover is None:
             current_cover = QPixmap(I('default_cover.png'))
+        current_cover.setDevicePixelRatio(QApplication.instance().devicePixelRatio())
 
-        self.blank = QPixmap(I('blank.png')).scaled(150, 200)
+        self.blank = QIcon(I('blank.png')).pixmap(*CoverDelegate.ICON_SIZE)
         self.cc = current_cover
         self.reset_covers(do_reset=False)
 
@@ -677,8 +664,10 @@ class CoversModel(QAbstractListModel):  # {{{
     def get_item(self, src, pmap, waiting=False):
         sz = '%dx%d'%(pmap.width(), pmap.height())
         text = (src + '\n' + sz)
-        scaled = pmap.scaled(150, 200, Qt.IgnoreAspectRatio,
-                Qt.SmoothTransformation)
+        scaled = pmap.scaled(
+            int(CoverDelegate.ICON_SIZE[0] * pmap.devicePixelRatio()), int(CoverDelegate.ICON_SIZE[1] * pmap.devicePixelRatio()),
+            Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
+        scaled.setDevicePixelRatio(pmap.devicePixelRatio())
         return (text, (scaled), pmap, waiting)
 
     def rowCount(self, parent=None):
@@ -707,6 +696,7 @@ class CoversModel(QAbstractListModel):  # {{{
         # Remove entries that are still waiting
         good = []
         pmap = {}
+
         def keygen(x):
             pmap = x[2]
             if pmap is None:
@@ -740,6 +730,12 @@ class CoversModel(QAbstractListModel):  # {{{
                 return self.index(r)
         return self.index(0)
 
+    def load_pixmap(self, data):
+        pmap = QPixmap()
+        pmap.loadFromData(data)
+        pmap.setDevicePixelRatio(QApplication.instance().devicePixelRatio())
+        return pmap
+
     def update_result(self, plugin_name, width, height, data):
         if plugin_name.endswith('}'):
             # multi cover plugin
@@ -749,8 +745,7 @@ class CoversModel(QAbstractListModel):  # {{{
                 return
             plugin = plugin[0]
             last_row = max(self.plugin_map[plugin])
-            pmap = QPixmap()
-            pmap.loadFromData(data)
+            pmap = self.load_pixmap(data)
             if pmap.isNull():
                 return
             self.beginInsertRows(QModelIndex(), last_row, last_row)
@@ -770,8 +765,7 @@ class CoversModel(QAbstractListModel):  # {{{
                     break
             if idx is None:
                 return
-            pmap = QPixmap()
-            pmap.loadFromData(data)
+            pmap = self.load_pixmap(data)
             if pmap.isNull():
                 return
             self.covers[idx] = self.get_item(plugin_name, pmap, waiting=False)
@@ -786,6 +780,7 @@ class CoversModel(QAbstractListModel):  # {{{
 
 # }}}
 
+
 class CoversView(QListView):  # {{{
 
     chosen = pyqtSignal()
@@ -799,7 +794,7 @@ class CoversView(QListView):  # {{{
         self.setWrapping(True)
         self.setResizeMode(self.Adjust)
         self.setGridSize(QSize(190, 260))
-        self.setIconSize(QSize(150, 200))
+        self.setIconSize(QSize(*CoverDelegate.ICON_SIZE))
         self.setSelectionMode(self.SingleSelection)
         self.setViewMode(self.IconMode)
 
@@ -867,6 +862,7 @@ class CoversView(QListView):  # {{{
 
 # }}}
 
+
 class CoversWidget(QWidget):  # {{{
 
     chosen = pyqtSignal()
@@ -929,7 +925,7 @@ class CoversWidget(QWidget):  # {{{
         if self.continue_processing:
             self.covers_view.clear_failed()
 
-        if self.worker.error is not None:
+        if self.worker.error and self.worker.error.strip():
             error_dialog(self, _('Download failed'),
                     _('Failed to download any covers, click'
                         ' "Show details" for details.'),
@@ -973,6 +969,7 @@ class CoversWidget(QWidget):  # {{{
 
 # }}}
 
+
 class LogViewer(QDialog):  # {{{
 
     def __init__(self, log, parent=None):
@@ -1021,6 +1018,7 @@ class LogViewer(QDialog):  # {{{
 
 # }}}
 
+
 class FullFetch(QDialog):  # {{{
 
     def __init__(self, current_cover=None, parent=None):
@@ -1136,6 +1134,7 @@ class FullFetch(QDialog):  # {{{
         return self.exec_()
 # }}}
 
+
 class CoverFetch(QDialog):  # {{{
 
     def __init__(self, current_cover=None, parent=None):
@@ -1145,7 +1144,7 @@ class CoverFetch(QDialog):  # {{{
         self.cover_pixmap = None
 
         self.setWindowTitle(_('Downloading cover...'))
-        self.setWindowIcon(QIcon(I('book.png')))
+        self.setWindowIcon(QIcon(I('default_cover.png')))
 
         self.l = l = QVBoxLayout()
         self.setLayout(l)
